@@ -95,6 +95,12 @@ windmill.controller = new function () {
       element = elementslib.Element.NAME(param_object.name);
     }
     //if name was passed
+    if(typeof param_object.value != "undefined") {
+      s = 'Looking up value '+ param_object.value;
+      //element = this.findElement("name=" + param_object.name)
+      element = elementslib.Element.VALUE(param_object.value);
+    }
+    //if name was passed
     if(typeof param_object.classname != "undefined") {
       s = 'Looking up classname '+ param_object.classname;
       element = elementslib.Element.CLASSNAME(param_object.classname);
@@ -163,12 +169,35 @@ windmill.controller = new function () {
       }
     }
     //Just making sure the page is fully loaded
-    setTimeout("cont()", 500);
+    setTimeout("cont()", 1);
   };
 
   this.stopLoop = function () {
     windmill.xhr.loopState = false;
   };
+  
+  //Store an attribute of a DOM element in the variable registry
+  this.storeVarFromLocAttrib = function (param_object) {
+    var element = this._lookupDispatch(param_object);
+    if (!element){ return false; }
+
+    var arr = param_object.options.split('|');
+    var varName = arr[0];
+    var attrib = arr[1];
+    
+    var attribValue = element[attrib];
+    
+    if (windmill.varRegistry.hasKey('{$'+varName+'}')){
+      windmill.varRegistry.removeItem('{$'+varName +'}');
+      windmill.varRegistry.addItem('{$'+varName +'}', attribValue);
+    }
+    else{
+      windmill.varRegistry.addItem('{$'+varName +'}', attribValue);
+    }
+    return true;
+
+  }
+  
   //expects a name and js param
   this.storeVarFromJS = function (param_object) {
     //extract the options
@@ -925,8 +954,7 @@ windmill.controller = new function () {
   	        rwaRecurse(iframeArray[i]);
           }
           catch(error){             
-           	windmill.ui.results.writeResult('There was a problem rewriting alert on one of your iframes, is it cross domain?' +
-  					  'Binding to all others.' + error);     
+           	windmill.ui.results.writeResult('Could not bind to iframe number '+ iframeCount +' '+error);     
           }
         }
     }
