@@ -51,9 +51,14 @@ var elementslib = new function(){
     domNode = nodeSearch(nodeByTagname, s);
     return returnOrThrow(s);
   };
-  this.Element.XPATH = function(s){
+  this.Element.VALUE = function(s){
+    locators.value = s;
+    domNode = nodeSearch(nodeByValue, s);
+    return returnOrThrow(s);
+  };
+  this.Element.XPATH = function(s, xb){
     locators.xpath = s;
-    domNode = nodeSearch(nodeByXPath, s);
+    domNode = nodeSearch(nodeByXPath, s, xb);
     //do the lookup, then set the domNode to the result
     return returnOrThrow(s);
   };
@@ -194,8 +199,34 @@ var elementslib = new function(){
     return this.document.getElementsByClassName(cn)[idx];
   };
   
+  //Lookup DOM node by value attribute
+  var nodeByValue = function (s) {
+    var getElementsByAttribute = function(oElm, strTagName, strAttributeName, strAttributeValue){
+        var arrElements = (strTagName == "*" && oElm.all)? oElm.all : oElm.getElementsByTagName(strTagName);
+        var arrReturnElements = new Array();
+        var oAttributeValue = (typeof strAttributeValue != "undefined")? new RegExp("(^|\\s)" + strAttributeValue + "(\\s|$)", "i") : null;
+        var oCurrent;
+        var oAttribute;
+        for(var i=0; i<arrElements.length; i++){
+            oCurrent = arrElements[i];
+            oAttribute = oCurrent.getAttribute && oCurrent.getAttribute(strAttributeName);
+            if(typeof oAttribute == "string" && oAttribute.length > 0){
+                if(typeof strAttributeValue == "undefined" || (oAttributeValue && oAttributeValue.test(oAttribute))){
+                    arrReturnElements.push(oCurrent);
+                }
+            }
+        }
+        return arrReturnElements;
+    }
+    var node = getElementsByAttribute(this.document, "*", "value", s);
+    if (node.length == 0){
+      return null;
+    }
+    return node[0];
+  };
+  
   //Lookup with xpath
-  var nodeByXPath = function (xpath) {
+  var nodeByXPath = function (xpath, xb) {
     var nsResolver = function (prefix) {
       if (prefix == 'html' || prefix == 'xhtml' || prefix == 'x') {
         return 'http://www.w3.org/1999/xhtml';
@@ -205,26 +236,19 @@ var elementslib = new function(){
         throw new Error("Unknown namespace: " + prefix + ".");
       }
     }
-    if (browser.isIE) {
-      //xpath = xpath.replace(/x:/g, '')
-      //making very specific xpath compatible with IE and FF
-      xpath = xpath.replace(/\[@.*?\]/g, '');
-    }
-
     // Use document.evaluate() if it's available
-    if (this.document.evaluate) {
+    if (this.document.evaluate && !xb) {
       return this.document.evaluate(xpath, this.document, nsResolver, 0, null).iterateNext();
     }
+    
+    xpath = xpath.replace(/\[@.*?\]/g, '');
     var expr = xpathParse(xpath.toUpperCase());
     var xpathResult = expr.evaluate(new ExprContext(this.document));
+    
     if (xpathResult && xpathResult.value) {
       return xpathResult.value[0];
-    }
-    // // If not, fall back to slower JavaScript implementation
-    //   var context = new ExprContext(this.document);
-    //   var xpathObj = xpathParse(xpath);
-    //   var xpathResult = xpathObj.evaluate(context);
-    //   
+    } 
+    
     return null;
   };
   
