@@ -28,12 +28,11 @@ var json_call = function(version, method, params) {
 
 var busyOn = function(){
   $('actionDD').style.visibility = "hidden";
-  $('loadRemote').style.display = "block";
   $('cover').style.display = "block";
 }
 var busyOff = function(){
+  jQuery("#loadMessage").html("Please wait, (Doing Stuff)...");        
   $('actionDD').style.visibility = "visible";
-  $('loadRemote').style.display = "none";
   $('cover').style.display = "none";
 }
 
